<?php

// Nom du fichier d'archive à créer
$archiveName = 'archive_site_' . date('Y-m-d') . '.zip';

// Création d'une nouvelle instance de ZipArchive
$zip = new ZipArchive();

// Variable pour stocker le statut de la compression
$compressionStatus = false;

// Ouverture de l'archive pour l'ajout de fichiers
if ($zip->open($archiveName, ZipArchive::CREATE) === TRUE) {
    // Fonction récursive pour ajouter tout le contenu du répertoire courant à l'archive
    addFolderToZip(".", $zip);
    // Fermeture de l'archive
    $zip->close();
    echo "L'archive $archiveName a été créée avec succès.\n";
    $compressionStatus = true;
} else {
    echo "Erreur lors de la création de l'archive.\n";
}

// Envoi de l'email
sendCompressionStatusEmail($compressionStatus, $archiveName);

/**
 * Fonction pour ajouter récursivement le contenu d'un dossier à l'archive ZIP
 * @param string $folder Le chemin du dossier à ajouter
 * @param ZipArchive $zipInstance L'instance de ZipArchive à laquelle ajouter le contenu
 * @param string $subfolder Chemin relatif du sous-dossier pour la structure de l'archive
 */
function addFolderToZip($folder, &$zipInstance, $subfolder = '') {
    // Ouvre le dossier
    $handle = opendir($folder);
    while (($f = readdir($handle)) !== false) {
        if ($f != '.' && $f != '..') {
            // Chemin complet vers le fichier ou dossier
            $filePath = "$folder/$f";
            // Ajoute le fichier ou le dossier à l'archive
            if (is_file($filePath)) {
                $zipInstance->addFile($filePath, $subfolder . $f);
            } elseif (is_dir($filePath)) {
                // Ajoute récursivement le contenu du sous-dossier
                addFolderToZip($filePath, $zipInstance, $subfolder . $f . '/');
            }
        }
    }
    closedir($handle);
}

/**
 * Fonction pour envoyer un email indiquant le statut de la compression
 * @param bool $status Le statut de la compression (true pour succès, false pour échec)
 * @param string $archiveName Le nom de l'archive créée
 */
function sendCompressionStatusEmail($status, $archiveName) {
    $to = 'sdaudiffret@gmail.com';
    $subject = 'Statut de la compression de l\'archive';
    $message = $status ? "La compression de l'archive $archiveName a réussi." : "La compression de l'archive a échoué.";
    $headers = 'From: no-reply@votredomaine.com' . "\r\n" .
               'Reply-To: no-reply@votredomaine.com' . "\r\n" .
               'X-Mailer: PHP/' . phpversion();

    mail($to, $subject, $message, $headers);
}

?>
